@@ -11,7 +11,7 @@ class PygfxRenderer(Renderer):
 
     def create_element(self, type: str) -> gfx.WorldObject:
         """Create pygfx element for the given type"""
-        type = type.lower()
+        type = type.lower().replace("-", "")
         if element_type := ELEMENT_TYPE_CACHE.get(type):
             return element_type()
 
@@ -44,7 +44,10 @@ class PygfxRenderer(Renderer):
     def set_attribute(self, obj, attr, value):
         if isinstance(obj, gfx.WorldObject):
             if attr in {"position", "scale"}:
-                value = gfx.linalg.Vector3(*value)
+                if attr == "scale" and isinstance(value, (int, float)):
+                    value = gfx.linalg.Vector3(value, value, value)
+                else:
+                    value = gfx.linalg.Vector3(*value)
             elif attr == "rotation":
                 value = gfx.linalg.Quaternion(*value)
             elif attr == "matrix":
