@@ -20,10 +20,17 @@ TYPE_MAPPING = {
     "spinbox": QtWidgets.QSpinBox,
     "statusbar": QtWidgets.QStatusBar,
     "textedit": QtWidgets.QTextEdit,
+    "toolbar": QtWidgets.QToolBar,
     "treeview": QtWidgets.QTreeView,
+    "treewidget": QtWidgets.QTreeWidget,
+    "treewidgetitem": QtWidgets.QTreeWidgetItem,
     "widget": QtWidgets.QWidget,
     "window": QtWidgets.QMainWindow,
     "action": QtGui.QAction,
+    "dock": QtWidgets.QDockWidget,
+    "itemmodel": QtGui.QStandardItemModel,
+    "itemselectionmodel": QtCore.QItemSelectionModel,
+    "standarditem": QtGui.QStandardItem,
 }
 
 # Default arguments for types that need
